import { Component, Input, OnInit } from "@angular/core";
import { CapabilityRequest } from "../../../../model/capability-request";
import * as dayjs from 'dayjs';
import * as relativeTime from 'dayjs/plugin/relativeTime';
import * as localizedFormat from 'dayjs/plugin/localizedFormat';
@Component({
  selector: "app-request-header",
  templateUrl: "./request-header.component.html",
  styleUrls: ["./request-header.component.scss"],
})
export class RequestHeaderComponent implements OnInit {
  @Input() capabilityRequest: CapabilityRequest;
  createdAt;
  updatedAt;

  constructor() {}

  ngOnInit(): void {
    this.createdAt = this.formatDate(this.capabilityRequest.created_at)
    this.updatedAt = this.formatDate(this.capabilityRequest.updated_at)
  }

  private formatDate(date): string {
    dayjs.extend(relativeTime)
    dayjs.extend(localizedFormat)

    var dateFromNow = dayjs(date).fromNow()
    var afterOneWeekDisplay = dateFromNow + " on " + dayjs(date).format('llll');
    return this.isOlderThanOneWeek(date) ? afterOneWeekDisplay : dateFromNow;
  }

  private isOlderThanOneWeek(date): boolean {
    const now = dayjs();
    date = dayjs(date)
    return now.diff(date, "week") ? true : false
  }
}
